=======
History
=======

0.4.0 (2018-02-17)
------------------

* Fix faiures from flake8 #30
* Improve CONTRIBUTIONG.rst and installation.rst #29
* Make add command not to failed duplicated ports #27
* Make setup.py load requirements.txt for dependencies
* Add update command
* Change base port number from 6000 to 49152


0.3.0 (2018-01-10)
------------------

* Automatic remote port assignment
* Add special handling when remote host is specified as localhost
* Check remote port is already used or not
* Make default value of --remote-host option localhost
* Add version command

0.2.0 (2018-01-09)
------------------

* Support automatic port assignment
* Change parameter format
* Add tests

0.1.0 (2018-01-02)
------------------

* First release on PyPI.
